@@ -265,23 +265,28 @@ public class GC extends GObject
 	    Handle colormapHandle = gdk_gc_get_colormap(getHandle());
 		if (colormapHandle == null)
 			return null;
-		GObject obj = retrieveGObject(colormapHandle);
+		GObject obj = getGObjectFromHandle(colormapHandle);
 		if (null != obj)
 			return (Colormap)obj;
 		return new Colormap(colormapHandle);
 	}
+    
+    public Screen getScreen() {
+        return new Screen(gdk_gc_get_screen(getHandle()));
+    }
+
 
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     native static final protected int getClipXOrigin (Handle obj);
     native static final protected int getClipYOrigin (Handle obj);
     native static final protected int getTsXOrigin (Handle obj);
     native static final protected int getTsYOrigin (Handle obj);
     native static final protected int gdk_gc_get_type ();
     native static final protected Handle gdk_gc_new (Handle drawable);
+    native static final protected Handle gdk_gc_get_screen(Handle gc);
     native static final protected void gdk_gc_set_foreground (Handle gc, Handle color);
     native static final protected void gdk_gc_set_background (Handle gc, Handle color);
+    native static final protected void gdk_gc_set_rgb_fg_color (Handle gc, Handle color);
+    native static final protected void gdk_gc_set_rgb_bg_color (Handle gc, Handle color);
     native static final protected void gdk_gc_set_function (Handle gc, int function);
     native static final protected void gdk_gc_set_fill (Handle gc, int fill);
     native static final protected void gdk_gc_set_tile (Handle gc, Handle tile);
@@ -295,16 +300,11 @@ public class GC extends GObject
     native static final protected void gdk_gc_set_exposures (Handle gc, boolean exposures);
     native static final protected void gdk_gc_set_line_attributes (Handle gc, int lineWidth, int 
         lineStyle, int capStyle, int joinStyle);
-    native static final protected void gdk_gc_set_dashes (Handle gc, int dashOffset, int [] dashList, 
-        int n);
-    native static final protected void gdk_gc_offset (Handle gc, int xOffset, int yOffset);
+    native static final protected void gdk_gc_set_dashes (Handle gc, int dashOffset, int [] dashList, int n);
     native static final protected void gdk_gc_copy (Handle dstGC, Handle srcGC);
     native static final protected void gdk_gc_set_colormap (Handle gc, Handle colormap);
     native static final protected Handle gdk_gc_get_colormap (Handle gc);
-    native static final protected void gdk_gc_set_rgb_fg_color (Handle gc, Handle color);
-    native static final protected void gdk_gc_set_rgb_bg_color (Handle gc, Handle color);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+    native static final protected void gdk_gc_offset (Handle gc, int xOffset, int yOffset);
+
 }
 
