@@ -52,7 +52,7 @@ public class AccelLabel extends Label
 	    Handle hndl = gtk_accel_label_get_accel_widget(getHandle());
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
