@@ -87,5 +87,8 @@ public class CellRenderer extends GObject
     native static final protected void gtk_cell_renderer_get_fixed_size (Handle cell, int [] width, int [] height);
     native static final protected void gtk_cell_renderer_stop_editing(Handle cell, boolean canceled);
 
+    /* Deprecated method.
+    native static final private void gtk_cell_renderer_editing_canceled(Handle cell);
+    */
 }
 
