@@ -337,7 +337,7 @@ public class ListStore extends TreeModel implements TreeSortable, TreeDragSource
 				      Handle bIter, int col ) {
 		TreeIterComparison method = TreeSortableHelper.getMethod( this, col );
 		if ( method != null ) {
-			TreeModel mdl = (TreeModel)retrieveGObject( model );
+			TreeModel mdl = (TreeModel)getGObjectFromHandle( model );
 			TreeIter a = new TreeIter( aIter, mdl );
 			TreeIter b = new TreeIter( bIter, mdl );
 			return method.compareTreeIters( mdl, a, b );
