@@ -51,9 +51,30 @@ public class SelectionData extends GObject
 		return gtk_selection_data_set_text( getHandle(), text );
 	}
 	
-	public boolean targetsIncludText() {
-		return gtk_selection_data_targets_include_text(getHandle());
-	}
+    /**
+     * Given that this SelectionData object holds a list of targets, 
+     * determines if any of the targets in targets can be used to provide text.
+     *
+     * @return TRUE if this SelectionData holds a list of targets, and a 
+     * suitable target for text is included, otherwise FALSE.
+     */
+    public boolean targetsIncludText() {
+        return gtk_selection_data_targets_include_text(getHandle());
+    }
+
+    /**
+     * Given that this SelectionData object holds a list of targets,
+     * determines if any of the targets in targets can be used to
+     * provide a {@link org.gnu.gdk.Pixbuf}.
+     *
+     * @param writable Whether to accept only targets for which GTK+ knows 
+     * how to convert a pixbuf into the format.
+     * @return TRUE if this SelectionData holds a list of targets, and a 
+     * suitable target for images is included, otherwise FALSE.
+     */
+    public boolean targetsIncludeImage( boolean writable ) {
+        return gtk_selection_data_targets_include_image( getHandle(), writable );
+    }
 
 	public Atom[] getTargets() {
 	    Handle hndls[] = gtk_selection_data_get_targets(getHandle());
@@ -94,6 +115,7 @@ public class SelectionData extends GObject
 	native static protected final boolean gtk_selection_data_set_text( Handle selectionData, String str );
 	native static protected final Handle[] gtk_selection_data_get_targets(Handle selectionData);
 	native static protected final boolean gtk_selection_data_targets_include_text(Handle selectionData);
+    native static final private boolean gtk_selection_data_targets_include_image(Handle selection_data, boolean writable);
 	native static protected final boolean gtk_selection_data_set_pixbuf(Handle selectionData, Handle pixbuf); 
 	native static protected final Handle gtk_selection_data_get_pixbuf(Handle selectionData);
 	native static protected final boolean gtk_selection_data_set_uris(Handle selectionData, String[] uris);
