@@ -80,7 +80,7 @@ public class TextMark extends GObject
 	 */
 	public TextBuffer getBuffer(){
 	    Handle hndl = gtk_text_mark_get_buffer(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TextBuffer)obj;
 		return new TextBuffer(hndl);
