@@ -14,6 +14,7 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.ToolBarEvent;
 import org.gnu.gtk.event.ToolBarListener;
@@ -34,7 +35,7 @@ public class ToolBar extends Container {
 		super(gtk_toolbar_new());
 	}
 	
-	public ToolBar(int hndl) {
+	public ToolBar(Handle hndl) {
 		super(hndl);
 	}
 	
@@ -198,8 +199,8 @@ public class ToolBar extends Container {
 	 * @return
 	 */
 	public ToolItem getItem(int position) {
-		int hndl = gtk_toolbar_get_nth_item(getHandle(), position);
-		GObject obj = retrieveGObject(hndl);
+	    Handle hndl = gtk_toolbar_get_nth_item(getHandle(), position);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (ToolItem)obj;
 		return new ToolItem(hndl);
@@ -359,42 +360,36 @@ public class ToolBar extends Container {
 		anEvtMap.addEvent("popup_context_menu", "handlePopupContextMenu", ToolBarEvent.Type.POPUP_CONTEXT_MENU, ToolBarListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
 	native static final protected int gtk_toolbar_get_type();
-	native static final protected int gtk_toolbar_new();
-	native static final protected void gtk_toolbar_set_orientation(int toolbar, int orientation);
-	native static final protected void gtk_toolbar_set_style(int toolbar, int style);
-	native static final protected void gtk_toolbar_set_tooltips(int toolbar, boolean enable);
-	native static final protected void gtk_toolbar_unset_style(int toolbar);
-	native static final protected int gtk_toolbar_get_orientation(int toolbar);
-	native static final protected int gtk_toolbar_get_style(int toolbar);
-	native static final protected int gtk_toolbar_get_icon_size(int toolbar);
-	native static final protected boolean gtk_toolbar_get_tooltips(int toolbar);
+	native static final protected Handle gtk_toolbar_new();
+	native static final protected void gtk_toolbar_set_orientation(Handle toolbar, int orientation);
+	native static final protected void gtk_toolbar_set_style(Handle toolbar, int style);
+	native static final protected void gtk_toolbar_set_tooltips(Handle toolbar, boolean enable);
+	native static final protected void gtk_toolbar_unset_style(Handle toolbar);
+	native static final protected int gtk_toolbar_get_orientation(Handle toolbar);
+	native static final protected int gtk_toolbar_get_style(Handle toolbar);
+	native static final protected int gtk_toolbar_get_icon_size(Handle toolbar);
+	native static final protected boolean gtk_toolbar_get_tooltips(Handle toolbar);
 	
 	// Deprecated Methods
-	native static final protected void gtk_toolbar_append_space(int toolbar);
-	native static final protected void gtk_toolbar_prepend_space(int toolbar);
-	native static final protected void gtk_toolbar_insert_space(int toolbar, int position);
-	native static final protected void gtk_toolbar_remove_space(int toolbar, int position);
-	native static final protected void gtk_toolbar_append_widget(int Toolbar, int Widget, String tooltipText, String tooltipPrivateText);
-	native static final protected void gtk_toolbar_prepend_widget(int Toolbar, int Widget, String tooltipText, String tooltipPrivateText);
-	native static final protected void gtk_toolbar_insert_widget(int toolbar, int widget, String tooltipText, String tooltipPrivateText, int position);
-	native static final protected void gtk_toolbar_set_icon_size(int toolbar, int iconSize);
-	native static final protected void gtk_toolbar_unset_icon_size(int toolbar);
+	native static final protected void gtk_toolbar_append_space(Handle toolbar);
+	native static final protected void gtk_toolbar_prepend_space(Handle toolbar);
+	native static final protected void gtk_toolbar_insert_space(Handle toolbar, int position);
+	native static final protected void gtk_toolbar_remove_space(Handle toolbar, int position);
+	native static final protected void gtk_toolbar_append_widget(Handle Toolbar, Handle widget, String tooltipText, String tooltipPrivateText);
+	native static final protected void gtk_toolbar_prepend_widget(Handle Toolbar, Handle widget, String tooltipText, String tooltipPrivateText);
+	native static final protected void gtk_toolbar_insert_widget(Handle toolbar, Handle widget, String tooltipText, String tooltipPrivateText, int position);
+	native static final protected void gtk_toolbar_set_icon_size(Handle toolbar, int iconSize);
+	native static final protected void gtk_toolbar_unset_icon_size(Handle toolbar);
 	
 	// New Methods
-	native static final protected void gtk_toolbar_insert(int toolbar, int item, int pos);
-	native static final protected int gtk_toolbar_get_item_index(int toolbar, int item);
-	native static final protected int gtk_toolbar_get_n_items(int toolbar);
-	native static final protected int gtk_toolbar_get_nth_item(int toolbar, int pos);
-	native static final protected boolean gtk_toolbar_get_show_arrow(int toolbar);
-	native static final protected void gtk_toolbar_set_show_arrow(int toolbar, boolean show);
-	native static final protected int gtk_toolbar_get_relief_style(int toolbar);
-	native static final protected int gtk_toolbar_get_drop_index(int toolbar, int x, int y);
-	native static final protected void gtk_toolbar_set_drop_highlight_item(int toolbar, int item, int index);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected void gtk_toolbar_insert(Handle toolbar, Handle item, int pos);
+	native static final protected int gtk_toolbar_get_item_index(Handle toolbar, Handle item);
+	native static final protected int gtk_toolbar_get_n_items(Handle toolbar);
+	native static final protected Handle gtk_toolbar_get_nth_item(Handle toolbar, int pos);
+	native static final protected boolean gtk_toolbar_get_show_arrow(Handle toolbar);
+	native static final protected void gtk_toolbar_set_show_arrow(Handle toolbar, boolean show);
+	native static final protected int gtk_toolbar_get_relief_style(Handle toolbar);
+	native static final protected int gtk_toolbar_get_drop_index(Handle toolbar, int x, int y);
+	native static final protected void gtk_toolbar_set_drop_highlight_item(Handle toolbar, Handle item, int index);
 }
