@@ -76,7 +76,7 @@ public class TreeViewColumn extends GObject {
 			return null;
 		CellRenderer[] cr = new CellRenderer[hndls.length];
 		for (int i = 0; i < hndls.length; i++) {
-			GObject obj = retrieveGObject(hndls[i]);
+			GObject obj = getGObjectFromHandle(hndls[i]);
 			if (null != obj)
 				cr[i] = (CellRenderer)obj;
 			else
@@ -235,7 +235,7 @@ public class TreeViewColumn extends GObject {
 	    Handle hndl = gtk_tree_view_column_get_widget(getHandle());
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -270,9 +270,9 @@ public class TreeViewColumn extends GObject {
 	}
 
 	/**
-	 * Sets the logical sortColumnId that this column sorts on when this column 
+	 * Sets the logical DataColumn that this column sorts on when this column 
 	 * is selected for sorting. Doing so makes the column header clickable.
-	 * @param sortColumnId The sortColumnId of the model to sort on.
+	 * @param column The DataColumn of the model to sort on.
 	 */
 	public void setSortColumn( DataColumn column ) {
 		gtk_tree_view_column_set_sort_column_id(getHandle(), column.getColumn() );
@@ -294,17 +294,20 @@ public class TreeViewColumn extends GObject {
 
 	/**
 	 * Changes the appearance of the sort indicator.
-	 *
-	 * <p>This does not actually sort the model. Use {@link #setSortColumnID(int)}
-	 * if you want automatic sorting support. This function is primarily for 
+	 * <p>
+	 * This does not actually sort the model. Use 
+         * {@link #setSortColumn} if you want automatic sorting 
+         * support. This function is primarily for 
 	 * custom sorting behavior, and should be used in conjunction with 
-	 * {@link #setSortColumnID(int)} to do that. For custom models, the mechanism will 
-	 * vary.
-	 * 
-	 * <p>The sort indicator changes direction to indicate normal sort or 
-	 * reverse sort. Note that you must have the sort indicator enabled to see 
-	 * anything when calling this function; 
+	 * {@link #setSortColumn} to do that. 
+         * For custom models, the mechanism will vary.
+	 * <p>
+	 * The sort indicator changes direction to indicate normal sort or 
+	 * reverse sort. Note that you must have the sort indicator enabled 
+         * to see anything when calling this function; 
+         * 
 	 * @see #setSortIndicator(boolean)
+         * @see #setSortColumn
 	 * @param order Sort order that the sort indicator should indicate
 	 */
 	public void setSortOrder(SortType order) {
