@@ -330,6 +330,7 @@ public class Window extends Bin {
 	
 	/**
 	 * Returns whether this window should appear in the task bar.
+	 * @return
 	 */
 	public boolean getSkipTaskbarHint() {
 		return gtk_window_get_skip_taskbar_hint(getHandle());
@@ -345,6 +346,7 @@ public class Window extends Bin {
 
 	/**
 	 * Returns whether the window should appear in the pager.
+	 * @return
 	 */
 	public boolean getSkipPagerHint() {
 		return gtk_window_get_skip_pager_hint(getHandle());
@@ -438,6 +440,51 @@ public class Window extends Bin {
 		return wins;
 	}
 	
+    /**
+     * Windows may set a hint asking the desktop environment not to receive 
+     * the input focus when the window is mapped. This function sets this hint.
+     *
+     * @param setting TRUE to let this window receive input focus on map.
+     */
+    public void setFocusOnMap( boolean setting ) {
+        gtk_window_set_focus_on_map( getHandle(), setting );
+    }
+    /**
+     * Gets the value set by {@link #setFocusOnMap}.
+     *
+     * @return TRUE if window should receive the input focus when mapped.
+     */
+    public boolean getFocusOnMap() {
+        return gtk_window_get_focus_on_map( getHandle() );
+    }
+
+    /**
+     * Sets the icon for the window from a named themed icon. See the docs 
+     * for {@link IconTheme} for more details.
+     * <p>
+     * Note that this has nothing to do with the WM_ICON_NAME property which 
+     * is mentioned in the ICCCM.
+     *
+     * @param name The name of the themed icon.
+     */
+    public void setIconName( String name ) {
+        gtk_window_set_icon_name( getHandle(), name );
+    }
+    /**
+     * Returns the name of the themed icon for the window.
+     *
+     * @return The icon name or NULL if the window has no themed icon.
+     */
+    public String getIconName() {
+        return gtk_window_get_icon_name( getHandle() );
+    }
+    /**
+     *
+     */
+    public void setDefaultIconName( String name ) {
+        gtk_window_set_default_icon_name( name );
+    }
+
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -526,4 +573,10 @@ public class Window extends Bin {
 	native static final protected void gtk_window_set_keep_above(Handle window, boolean setting);
 	native static final protected void gtk_window_set_keep_below(Handle window, boolean setting);
 
+    // GTK 2.6 additions.
+    native static final private void gtk_window_set_focus_on_map(Handle window, boolean setting);
+    native static final private boolean gtk_window_get_focus_on_map(Handle window);
+    native static final private void gtk_window_set_icon_name(Handle window, String name);
+    native static final private String gtk_window_get_icon_name(Handle window);
+    native static final private void gtk_window_set_default_icon_name(String name);
 }
