@@ -8,8 +8,11 @@
  */
 
 package org.gnu.pango;
+
 import org.gnu.glib.GObject;
 import org.gnu.glib.Handle;
+import org.gnu.glib.Type;
+
 /**
  * Pango supports a flexible architecture where a particular rendering
  * architecture can supply an implementation of fonts. The PangoFont structure
@@ -18,6 +21,9 @@ import org.gnu.glib.Handle;
  */
 public class Font extends GObject 
 {
+    public Font() { 
+        super( getType() ); 
+    }
 
 	/**
 	 * Returns a description of the font.
@@ -43,17 +49,18 @@ public class Font extends GObject
 		return new FontMetrics( pango_font_get_metrics(getHandle(), lang.getHandle()) );
 	}
 
+	/**
+	 * Retrieve the runtime type used by the GLib library.
+	 */
+	public static Type getType() {
+		return new Type(pango_font_get_type());
+	}
 
 
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     native static final protected int pango_font_get_type ();
     native static final protected Handle pango_font_describe (Handle font);
     native static final protected Handle pango_font_get_coverage (Handle font, Handle language);
     native static final protected Handle pango_font_get_metrics (Handle font, Handle language);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+
 }
 
